@@ -15,8 +15,9 @@ Examples
     srf = SRFData(api_key='...')
 
     # use a file-based http cache
-    from cachecontrol.caches import FileCache
-    srf = SRFData(api_key='...', cache=FileCache('/var/cache/srf_client'))
+    from cachecontrol.caches import SeparateBodyFileCache
+    srf = SRFData(api_key='...',
+                  cache=SeparateBodyFileCache('/var/cache/srf_client'))
 
     # get last recorded leg
     leg = srf.legs.find_all().last.items[-1]
