@@ -142,6 +142,7 @@ class Vehicle:
     :param weight_class: Max weight class (tonnes)
     :param euro_standard: European emission standard
     :param description: Additional description/notes
+    :param outfit_weight: Unloaded weight in standard configuration
     """
 
     _client: 'client.SRFData'
@@ -157,6 +158,7 @@ class Vehicle:
     weight_class: Optional[float] = None
     euro_standard: Optional[int] = None
     description: Optional[str] = None
+    outfit_weight: Optional[int] = None
 
     @property
     def organisation(self) -> 'Organisation':  # noqa: D102
